@@ -1,11 +1,12 @@
+# pep8: noqa
 from .core import *
 from .relationship_manager import (NotConnected, OUTGOING, INCOMING, EITHER,
-        RelationshipTo, RelationshipFrom, Relationship)
+        RelationshipTo, RelationshipFrom, Relationship, RelationshipManager, RelationshipDefinition)
 from .relationship import StructuredRel
 from .cardinality import (AttemptedCardinalityViolation,
         CardinalityViolation, ZeroOrMore, OneOrMore, ZeroOrOne, One)
 from .properties import (StringProperty, IntegerProperty, AliasProperty,
         FloatProperty, BooleanProperty, DateTimeProperty, DateProperty,
-        JSONProperty)
-from .exception import InflateError, DeflateError, UniqueProperty
+        JSONProperty, ArrayProperty)
+from .exception import InflateError, DeflateError, UniqueProperty, CypherException, MultipleNodesReturned
 from .signals import SIGNAL_SUPPORT
