@@ -1,4 +1,4 @@
-from .relationship_manager import RelationshipManager, ZeroOrMore
+from .relationship_manager import RelationshipManager, ZeroOrMore # noqa
 
 
 class ZeroOrOne(RelationshipManager):
@@ -64,8 +64,8 @@ class One(RelationshipManager):
         raise AttemptedCardinalityViolation("Cardinality one, cannot disconnect use reconnect")
 
     def connect(self, obj, properties=None):
-        if not self.origin.__node__:
-            raise Exception("Node has not been saved cannot connect!")
+        if not hasattr(self.source, '_id'):
+            raise ValueError("Node has not been saved cannot connect!")
         if len(self):
             raise AttemptedCardinalityViolation("Node already has one relationship")
         else:
