@@ -11,6 +11,6 @@ def test_save_to_model_with_extras():
     u = UserProf(email='jim@test.com', age=3, bar=99)
     u.foo = True
     assert u.save()
-    u = UserProf.index.get(age=3)
+    u = UserProf.nodes.get(age=3)
     assert u.foo is True
     assert u.bar == 99
